@@ -7,25 +7,25 @@ use base qw/WG::API/;
  
 =head1 NAME
 
-WG::API::Auth - The great new WG::API::Auth!
+WG::API::Auth  - Auth-module with using OpenID for work with WG PAPI
 
 =head1 VERSION
 
-Version v0.02
+Version v0.03
 
 =cut
 
-our $VERSION = 'v0.02';
+our $VERSION = 'v0.03';
 
 =head1 SYNOPSIS
 
-Quick summary of what the module does.
+This module implements the possibility of authorization, prolongate and logout from the center of development.
 
-Perhaps a little code snippet.
+    use WG::API::Auth;
 
-    use WG::API;
-
-    my $foo = WG::API->login();
+    my $response = WG::API::Auth->new({ application_id => 'demo' })->login({ nofollow => '1', redirect_uri => 'yoursite.com/response' } );
+    
+    my $redirect_uri = $response->{ 'location' };
     ...
 
 =head1 METHODS
@@ -34,6 +34,10 @@ Perhaps a little code snippet.
 
 =head3 login
 
+Method authenticates user based on Wargaming.net ID (OpenID) which is used in World of Tanks, World of Tanks Blitz, World of Warplanes, and WarGag.ru. To log in, player must enter email and password used for creating account, or use a social network profile. Authentication is not available for iOS Game Center users in the following cases: the account is not linked to a social network account, or email and password are not specified in the profile.
+
+Information on authorization status is sent to URL specified in redirect_uri parameter.
+
 =cut
 
 sub login { 
@@ -44,12 +48,20 @@ sub login {
 
 =head3 prolongate
 
+Method generates new access_token based on the current token.
+
+This method is used when the player is still using the application but the current access_token is about to expire.
+
 =cut
 
 sub prolongate { $_[0]->_request( 'post', 'auth/prolongate', ['access_token', 'expires_at'], ['access_token'], $_[1] ) }
 
 =head3 logout
 
+Method deletes user's access_token.
+
+After this method is called, access_token becomes invalid.
+
 =cut
 
 sub logout { $_[0]->_request( 'post', 'auth/logout', ['access_token'], ['access_token'], $_[1] ) }
@@ -62,33 +74,24 @@ sub _init {
 
     return $self;
 }
-=head1 AUTHOR
-
-Cyrill Novgorodcev, C<< <cynovg at cpan.org> >>
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-wg-api at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=WG-API>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
-
-
-
+Please report any bugs or feature requests to C<cynovg at cpan.org>, or through the web interface at L<https://github.com/cynovg/WG-API/issues>.  I will be notified, and then you'll automatically be notified of progress on your bug as I make changes.
 
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
 
-    perldoc WG::API::Auth
-
+    perldoc WG::API
 
 You can also look for information at:
 
 =over 4
 
-=item * RT: CPAN's request tracker (report bugs here)
+=item * RT: GitHub's request tracker (report bugs here)
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=WG-API>
+L<https://github.com/cynovg/WG-API/issues>
 
 =item * AnnoCPAN: Annotated CPAN documentation
 
@@ -107,7 +110,15 @@ L<http://search.cpan.org/dist/WG-API/>
 
 =head1 ACKNOWLEDGEMENTS
 
-=cut
+...
+
+=head1 SEE ALSO
+
+WG API Reference L<http://ru.wargaming.net/developers/>
+
+=head1 AUTHOR
+
+cynovg , C<< <cynovg at cpan.org> >>
 
 =head1 LICENSE AND COPYRIGHT
 
