@@ -6,15 +6,15 @@ use warnings;
 
 =head1 NAME
 
-WG::API::Error - The great new WG::API::Error!
+WG::API::Error - module for work with API error 
 
 =head1 VERSION
 
-Version v0.02
+Version v0.03
 
 =cut
 
-our $VERSION = 'v0.02';
+our $VERSION = 'v0.03';
 
 
 =head1 SYNOPSIS
@@ -29,11 +29,10 @@ Perhaps a little code snippet.
     ...
     say $wg_error->code;
 
-=head1 SUBROUTINES/METHODS
 
-=head2 CONSTRUCTOR
+=head1 CONSTRUCTOR
 
-=head3 new
+=head2 new
 
 Create new error object.
 
@@ -95,28 +94,50 @@ sub _parse {
     return;
 }
 
-=head1 AUTHOR
-
-Cyrill Novgorodcev, C<< <cynovg at cpan.org> >>
-
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-wg-api-error at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=WG-API-Error>.  I will be notified, and then you'll
-automatically be notified of progress on your bug as I make changes.
-
-
-
+Please report any bugs or feature requests to C<cynovg at cpan.org>, or through the web interface at L<https://github.com/cynovg/WG-API/issues>.  I will be notified, and then you'll automatically be notified of progress on your bug as I make changes.
 
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
 
-    perldoc WG::API::Error
+    perldoc WG::API
+
+You can also look for information at:
+
+=over 4
+
+=item * RT: GitHub's request tracker (report bugs here)
+
+L<https://github.com/cynovg/WG-API/issues>
+
+=item * AnnoCPAN: Annotated CPAN documentation
+
+L<http://annocpan.org/dist/WG-API>
+
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/d/WG-API>
+
+=item * Search CPAN
+
+L<http://search.cpan.org/dist/WG-API/>
+
+=back
+
+
+=head1 ACKNOWLEDGEMENTS
+
+...
 
 =head1 SEE ALSO
 
-    perldoc WG::API
+WG API Reference L<http://ru.wargaming.net/developers/>
+
+=head1 AUTHOR
+
+cynovg , C<< <cynovg at cpan.org> >>
 
 =head1 LICENSE AND COPYRIGHT
 
